/*****************************************************************************
 *                        Web3d.org Copyright (c) 2001
 *                               Java Source
 *
 * This source is licensed under the GNU LGPL v2.1
 * Please read http://www.gnu.org/copyleft/lgpl.html for more information
 *
 * This software comes with the standard NO WARRANTY disclaimer for any
 * purpose. Use it at your own risk. If there's a problem you get to fix it.
 *
 ****************************************************************************/

package org.j3d.aviatrix3d;

// External imports
// None

// Local imports
// None

/**
 * Handles the scenegraph maintenance and culling operations.
 * <p>
 *
 * The culling phase generates a list of nodes to render.
 * A future optimization will sort the render list by OGL state.
 * <p>
 *
 * The culling stage is responsible for looking at the offscreen renderable
 * surfaces as well as the main screen. Since most scenes will not require
 * any offscreen rendering, convenience methods are defined to allow the user
 * to turn on/off these checks. Offscreen rendering, and the checking for
 * extra renderables can be a huge CPU hog so it is advisable to make sure that
 * it is turned off if you don't need it. An ideal implementation will be able
 * to handle dynamically switching between the two states between frames
 * without the need to restart.
 *
 * @author Justin Couch
 * @version $Revision: 1.6 $
 */
public interface CullStage
{
    /**
     * Set the flag for whether to check for offscreen textures or not. By
     * default, this flag is set to true.
     *
     * @param state true if offscreen textures should be looked for
     */
    public void setOffscreenCheckEnabled(boolean state);

    /**
     * Find out what the current offscreen check state is.
     *
     * @return true if the checking is being performed
     */
    public boolean isOffscreenCheckEnabled();

    /**
     * Update and cull the scenegraph. This generates an ordered list
     * of nodes to render. It will not return until the culling is complete.
     *
     * @param scene The scene instance to cull
     * @param buffer The buffer ID to use to output the data to when
     *   multi-threaded
     */
    public void cull(Scene scene, int buffer);

    /**
     * Register a reciever for the output of the sorter. If the value is null,
     * it will clear the currently set receiver.
     *
     * @param sgr The receiver instance to add or null
     */
    public void setCulledGeometryReceiver(CulledGeometryReceiver sgr);
}