/*****************************************************************************
 *                        Web3d.org Copyright (c) 2003
 *                               Java Source
 *
 * This source is licensed under the GNU LGPL v2.1
 * Please read http://www.gnu.org/copyleft/lgpl.html for more information
 *
 * This software comes with the standard NO WARRANTY disclaimer for any
 * purpose. Use it at your own risk. If there's a problem you get to fix it.
 *
 ****************************************************************************/

package org.j3d.aviatrix3d;

// Standard imports
import java.util.HashMap;

import net.java.games.jogl.GL;
import net.java.games.jogl.GLU;

// Local imports
// None

/**
 * Node that handles fragment shader implementation
 * <p>
 *
 *
 * @author Justin Couch
 * @version $Revision: 1.5 $
 */
public class FragmentShader extends ShaderProgram
{
    /**
     * Constructs a TexCoordGeneration with default values.
     */
    public FragmentShader()
    {
    }

    /**
     * Set up the rendering state now.
     *
     * @param gl The gl context to draw with
     * @param glu The utility context to draw with
     */
    public void renderState(GL gl, GLU glu)
    {
        if(programString == null)
            return;

        // do we need to re-generate the program?
        if(programChanged)
        {
            int[] prog_tmp = new int[1];
            gl.glGenProgramsARB(1, prog_tmp);
            programId = prog_tmp[0];

            gl.glBindProgramARB(GL.GL_FRAGMENT_PROGRAM_ARB, programId);
            gl.glProgramStringARB(GL.GL_FRAGMENT_PROGRAM_ARB,
                                  GL.GL_PROGRAM_FORMAT_ASCII_ARB,
                                  programString.length(),
                                  programString);
            programChanged = false;
        }

        gl.glBindProgramARB(GL.GL_FRAGMENT_PROGRAM_ARB, programId);
        gl.glEnable(GL.GL_FRAGMENT_PROGRAM_ARB);
    }

    /*
     * This method is called after a node has been rendered.  This method
     * must be re-entrant.
     *
     * @param gl The gl context to draw with
     * @param glu The utility context to draw with
     */
    public void restoreState(GL gl, GLU glu)
    {
        gl.glDisable(GL.GL_VERTEX_PROGRAM_ARB);
    }
}